demoSample: Sample table of demographic information

demoSampleR Documentation

Sample table of demographic information

Description

The data are artificial and do not correspond to real patients.

Usage

demoSample

Format

A data table with the following columns:

  • person_id: Character vector of the identifier for each person in the cohort

  • sex: Character vector indicating biological sex

See Also

getWeights(), getScores()


phers documentation built on March 3, 2026, 9:07 a.m.

Related to demoSample in phers...